@@ -2,19 +2,20 @@
 #define CORE_BSINC_TABLES_H
 
 #include <array>
+#include <span>
 
-#include "alspan.h"
 #include "bsinc_defs.h"
-
+#include "opthelpers.h"
 
 struct BSincTable {
     float scaleBase, scaleRange;
     std::array<unsigned int,BSincScaleCount> m;
     std::array<unsigned int,BSincScaleCount> filterOffset;
-    al::span<const float> Tab;
+    std::span<const float> Tab;
 };
 
-extern const BSincTable gBSinc12;
-extern const BSincTable gBSinc24;
+DECL_HIDDEN extern constinit const BSincTable gBSinc12;
+DECL_HIDDEN extern constinit const BSincTable gBSinc24;
+DECL_HIDDEN extern constinit const BSincTable gBSinc48;
 
 #endif /* CORE_BSINC_TABLES_H */
